@@ -1,7 +1,7 @@
 /*
  * This file is part of the planetblupi source code
  * Copyright (C) 1997, Daniel Roux & EPSITEC SA
- * Copyright (C) 2017-2018, Mathieu Schroeter
+ * Copyright (C) 2017-2019, Mathieu Schroeter
  * http://epsitec.ch; http://www.blupi.org; http://github.com/blupi-games
  *
  * This program is free software: you can redistribute it and/or modify
@@ -77,10 +77,11 @@ bool        g_restoreMidi = false; // restore music playback based on midi files
 bool        g_renderQuality = true; // use the best render quality with scaling
 int         g_settingsOverload = 0;
 
-bool        g_bTermInit = false; // initialisation en cours
-Uint32      g_lastPhase = 999;
-RestartMode g_restart   = RestartMode::NO;
-static bool g_pause;
+bool          g_bTermInit = false; // initialisation en cours
+Uint32        g_lastPhase = 999;
+RestartMode   g_restart   = RestartMode::NO;
+static bool   g_pause;
+static Uint32 g_prevPhase = 0;
 
 #ifdef USE_CURL
 struct url_data {
@@ -292,6 +293,27 @@ Update (void)
       g_pEvent->ChangePhase (EV_PHASE_WINMOVIE); // win
   }
 
+  if (g_prevPhase != phase)
+  {
+    Point pos;
+
+    pos.x = LXIMAGE () / 2;
+    pos.y = LYIMAGE () / 2;
+
+    if (phase == EV_PHASE_LOST)
+    {
+      if (!g_pSound->PlayImage (SOUND_LOST, pos))
+        g_pSound->PlayImage (SOUND_GOAL, pos);
+    }
+    else if (phase == EV_PHASE_WIN || phase == EV_PHASE_LASTWIN)
+    {
+      if (!g_pSound->PlayImage (SOUND_WIN, pos))
+        g_pSound->PlayImage (SOUND_GOAL, pos);
+    }
+  }
+
+  g_prevPhase = phase;
+
   return display;
 }
 
@@ -361,7 +383,7 @@ HandleEvent (const SDL_Event & event)
         totalDim.y = 66;
         iconDim.x  = 64;
         iconDim.y  = 66 / 2;
-        g_pPixmap->Cache (CHHILI, "image/hili.png", totalDim, iconDim);
+        g_pPixmap->Cache (CHHILI, "hili.png", totalDim, iconDim);
       }
       SDL_SetWindowTitle (g_window, gettext ("Planet Blupi"));
       if (g_pSound != nullptr)
@@ -865,9 +887,9 @@ DoInit (int argc, char * argv[], bool & exit)
   iconDim.x  = 0;
   iconDim.y  = 0;
 #if _INTRO
-  if (!g_pPixmap->Cache (CHBACK, "image/intro1.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHBACK, "intro1.png", totalDim, iconDim))
 #else
-  if (!g_pPixmap->Cache (CHBACK, "image/init.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHBACK, "init.png", totalDim, iconDim))
 #endif
     return EXIT_FAILURE;
 
@@ -888,7 +910,7 @@ DoInit (int argc, char * argv[], bool & exit)
   totalDim.y = DIMCELY * 2 * 6;
   iconDim.x  = DIMCELX * 2;
   iconDim.y  = DIMCELY * 2;
-  if (!g_pPixmap->Cache (CHFLOOR, "image/floor000.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHFLOOR, "floor000.png", totalDim, iconDim))
   {
     InitFail ("Cache floor000.png");
     return EXIT_FAILURE;
@@ -898,13 +920,13 @@ DoInit (int argc, char * argv[], bool & exit)
   totalDim.y = DIMOBJY * 8;
   iconDim.x  = DIMOBJX;
   iconDim.y  = DIMOBJY;
-  if (!g_pPixmap->Cache (CHOBJECT, "image/obj000.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHOBJECT, "obj000.png", totalDim, iconDim))
   {
     InitFail ("Cache obj000.png");
     return EXIT_FAILURE;
   }
 
-  if (!g_pPixmap->Cache (CHOBJECTo, "image/obj-o000.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHOBJECTo, "obj-o000.png", totalDim, iconDim))
   {
     InitFail ("Cache obj-o000.png");
     return EXIT_FAILURE;
@@ -914,7 +936,7 @@ DoInit (int argc, char * argv[], bool & exit)
   totalDim.y = DIMBLUPIY * 23;
   iconDim.x  = DIMBLUPIX;
   iconDim.y  = DIMBLUPIY;
-  if (!g_pPixmap->Cache (CHBLUPI, "image/blupi.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHBLUPI, "blupi.png", totalDim, iconDim))
   {
     InitFail ("Cache blupi.png");
     return EXIT_FAILURE;
@@ -924,7 +946,7 @@ DoInit (int argc, char * argv[], bool & exit)
   totalDim.y = 66;
   iconDim.x  = 64;
   iconDim.y  = 66 / 2;
-  if (!g_pPixmap->Cache (CHHILI, "image/hili.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHHILI, "hili.png", totalDim, iconDim))
   {
     InitFail ("Cache hili.png");
     return EXIT_FAILURE;
@@ -934,7 +956,7 @@ DoInit (int argc, char * argv[], bool & exit)
   totalDim.y = DIMCELY * 2 * 5;
   iconDim.x  = DIMCELX * 2;
   iconDim.y  = DIMCELY * 2;
-  if (!g_pPixmap->Cache (CHFOG, "image/fog.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHFOG, "fog.png", totalDim, iconDim))
   {
     InitFail ("Cache fog.png");
     return EXIT_FAILURE;
@@ -944,7 +966,7 @@ DoInit (int argc, char * argv[], bool & exit)
   totalDim.y = DIMCELY * 2 * 1;
   iconDim.x  = DIMCELX * 2;
   iconDim.y  = DIMCELY * 2;
-  if (!g_pPixmap->Cache (CHMASK1, "image/mask1.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHMASK1, "mask1.png", totalDim, iconDim))
   {
     InitFail ("Cache mask1.png");
     return EXIT_FAILURE;
@@ -954,7 +976,7 @@ DoInit (int argc, char * argv[], bool & exit)
   totalDim.y = DIMCELY * 2 * 1;
   iconDim.x  = DIMCELX * 2;
   iconDim.y  = DIMCELY * 2;
-  if (!g_pPixmap->Cache (CHMASK2, "image/mask2.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHMASK2, "mask2.png", totalDim, iconDim))
   {
     InitFail ("Cache mask2.png");
     return EXIT_FAILURE;
@@ -964,7 +986,7 @@ DoInit (int argc, char * argv[], bool & exit)
   totalDim.y = DIMBUTTONY * 21;
   iconDim.x  = DIMBUTTONX;
   iconDim.y  = DIMBUTTONY;
-  if (!g_pPixmap->Cache (CHBUTTON, "image/button00.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHBUTTON, "button00.png", totalDim, iconDim))
   {
     InitFail ("Cache button00.png");
     return EXIT_FAILURE;
@@ -974,27 +996,27 @@ DoInit (int argc, char * argv[], bool & exit)
   totalDim.y = DIMJAUGEY * 4;
   iconDim.x  = DIMJAUGEX;
   iconDim.y  = DIMJAUGEY;
-  if (!g_pPixmap->Cache (CHJAUGE, "image/jauge.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHJAUGE, "jauge.png", totalDim, iconDim))
   {
     InitFail ("Cache jauge.png");
     return EXIT_FAILURE;
   }
 
   totalDim.x = DIMTEXTX * 16;
-  totalDim.y = DIMTEXTY * 9 * 3;
+  totalDim.y = DIMTEXTY * 16 * 3;
   iconDim.x  = DIMTEXTX;
   iconDim.y  = DIMTEXTY;
-  if (!g_pPixmap->Cache (CHTEXT, "image/text.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHTEXT, "text.png", totalDim, iconDim))
   {
     InitFail ("Cache text.png");
     return EXIT_FAILURE;
   }
 
   totalDim.x = DIMLITTLEX * 16;
-  totalDim.y = DIMLITTLEY * 9;
+  totalDim.y = DIMLITTLEY * 16;
   iconDim.x  = DIMLITTLEX;
   iconDim.y  = DIMLITTLEY;
-  if (!g_pPixmap->Cache (CHLITTLE, "image/little.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHLITTLE, "little.png", totalDim, iconDim))
   {
     InitFail ("Cache little.png");
     return EXIT_FAILURE;
@@ -1004,7 +1026,7 @@ DoInit (int argc, char * argv[], bool & exit)
   totalDim.y = 52;
   iconDim.x  = 426;
   iconDim.y  = 52;
-  if (!g_pPixmap->Cache (CHBIGNUM, "image/bignum.png", totalDim, iconDim))
+  if (!g_pPixmap->Cache (CHBIGNUM, "bignum.png", totalDim, iconDim))
   {
     InitFail ("Cache bignum.png");
     return EXIT_FAILURE;
