@@ -1,7 +1,7 @@
 /*
  * This file is part of the planetblupi source code
  * Copyright (C) 1997, Daniel Roux & EPSITEC SA
- * Copyright (C) 2017, Mathieu Schroeter
+ * Copyright (C) 2017-2018, Mathieu Schroeter
  * http://epsitec.ch; http://www.blupi.org; http://github.com/blupi-games
  *
  * This program is free software: you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 
 #pragma once
 
-#include <SDL2/SDL_stdinc.h>
+#include <SDL_stdinc.h>
 
 Sint16 * GetListMoves (Sint32 rank);
 Sint16 * GetListIcons (Sint32 rank);
