@@ -248,7 +248,7 @@ CDecor::LoadImages ()
   totalDim.y = DIMCELY * 2 * 6;
   iconDim.x  = DIMCELX * 2;
   iconDim.y  = DIMCELY * 2;
-  snprintf (filename, sizeof (filename), "image/floor%.3d.png", m_region);
+  snprintf (filename, sizeof (filename), "floor%.3d.png", m_region);
   if (!m_pPixmap->Cache (CHFLOOR, filename, totalDim, iconDim))
     return false;
 
@@ -256,11 +256,11 @@ CDecor::LoadImages ()
   totalDim.y = DIMOBJY * 8;
   iconDim.x  = DIMOBJX;
   iconDim.y  = DIMOBJY;
-  snprintf (filename, sizeof (filename), "image/obj%.3d.png", m_region);
+  snprintf (filename, sizeof (filename), "obj%.3d.png", m_region);
   if (!m_pPixmap->Cache (CHOBJECT, filename, totalDim, iconDim))
     return false;
 
-  snprintf (filename, sizeof (filename), "image/obj-o%.3d.png", m_region);
+  snprintf (filename, sizeof (filename), "obj-o%.3d.png", m_region);
   if (!m_pPixmap->Cache (CHOBJECTo, filename, totalDim, iconDim))
     return false;
 
@@ -1346,7 +1346,8 @@ CDecor::Build (Rect clip, Point posMouse)
             tPos = pos;
             tPos.x += 9;
             tPos.y -= 24;
-            m_pPixmap->DrawIcon (-1, CHBUTTON, 46, tPos);
+            m_pPixmap->DrawIcon (
+              -1, CHBUTTON, IsRightReading () ? 115 : 46, tPos);
           }
 
           // Dessine blupi
@@ -1538,7 +1539,7 @@ term:
       const auto text = GetResHili (posMouse);
       if (text)
       {
-        posMouse.x += 10;
+        posMouse.x += IsRightReading () ? 0 : 10;
         posMouse.y += 20;
         DrawText (m_pPixmap, posMouse, text);
       }
@@ -1843,7 +1844,8 @@ CDecor::CelOkForAction (
       GetFloor (cel, channel, icon);
       if ( // mine ?
         action == EV_ACTION_BUILD4 &&
-        ((!g_restoreBugs && !m_decorMem[cel.x / 2][cel.y / 2].flagged) || // fixed
+        ((!g_restoreBugs &&
+          !m_decorMem[cel.x / 2][cel.y / 2].flagged) ||          // fixed
          (g_restoreBugs && (channel != CHFLOOR || icon != 71)))) // funny bug
       {
         error = Errors::GROUND; // sol pas adéquat
@@ -3504,4 +3506,4 @@ void
 CDecor::InvalidateGrounds ()
 {
   m_bGroundRedraw = true;
-}
\ No newline at end of file
+}
