@@ -1,7 +1,7 @@
 /*
  * This file is part of the planetblupi source code
  * Copyright (C) 1997, Daniel Roux & EPSITEC SA
- * Copyright (C) 2017, Mathieu Schroeter
+ * Copyright (C) 2017-2018, Mathieu Schroeter
  * http://epsitec.ch; http://www.blupi.org; http://github.com/blupi-games
  *
  * This program is free software: you can redistribute it and/or modify
@@ -52,6 +52,10 @@ typedef struct {
 // Cette structure doit être la plus petite possible, car
 // il en existe un tableau de 100x100 = 10'000 cellules !
 
+typedef struct : Cellule {
+  bool flagged; // when a flag has been built for the iron
+} CellMem;
+
 // Descripteur d'un blupi animé.
 #define MAXBLUPI 100
 #define MAXUSED 50
@@ -366,9 +370,9 @@ public:
   void   StatisticDraw ();
   void   GenerateStatictic ();
   bool   StatisticDown (Point pos);
-  bool   StatisticMove (Point pos);
+  bool   StatisticMove (Point pos, bool & disable);
   bool   StatisticUp (Point pos);
-  Sint32 StatisticDetect (Point pos);
+  Sint32 StatisticDetect (Point pos, bool & disable);
 
   // Chemin.cpp
   void   CheminMemPos (Sint32 exRank);
@@ -457,6 +461,8 @@ public:
   void UndoBack ();
   bool IsUndo ();
 
+  void InvalidateGrounds ();
+
 protected:
   bool   GetSeeBits (Point cel, char * pBits, Sint32 index);
   Sint32 GetSeeIcon (char * pBits, Sint32 index);
@@ -466,6 +472,7 @@ protected:
   CPixmap * m_pPixmap;
   Cellule * m_pUndoDecor;
   Cellule   m_decor[MAXCELX / 2][MAXCELY / 2];
+  CellMem   m_decorMem[MAXCELX / 2][MAXCELY / 2];
   Sint16    m_rankBlupi[MAXCELX][MAXCELY];
   Blupi     m_blupi[MAXBLUPI];
   Move      m_move[MAXMOVE];
