@@ -98,6 +98,17 @@ GetLocale ()
   return gettext ("en");
 }
 
+bool
+IsRightReading (const char * text)
+{
+  auto isRight = false;
+  if (text)
+    isRight = strchr (text, 0xD7) != nullptr;
+  else
+    isRight = GetLocale () == "he";
+  return isRight;
+}
+
 // Retourne le nom de dossier en cours.
 
 std::string
