@@ -40,6 +40,7 @@ std::string GetBaseDir ();
 std::string GetShareDir ();
 std::string GetBinDir ();
 std::string GetLocale ();
+bool        IsRightReading (const char * text = nullptr);
 extern void AddUserPath (std::string & pFilename);
 
 enum Location { LOCATION_ABSOLUTE, LOCATION_BASE, LOCATION_USER };
@@ -68,4 +69,12 @@ basename (char * path)
   snprintf (basename, sizeof (basename), "%s%s", fname, ext);
   return basename;
 }
-#endif /* _WIN32 */
\ No newline at end of file
+#endif /* _WIN32 */
+#ifdef EMSCRIPTEN
+static inline char *
+basename (char * filename)
+{
+  char * p = strrchr (filename, '/');
+  return p ? p + 1 : filename;
+}
+#endif /* EMSCRIPTEN */
