@@ -83,7 +83,6 @@ CSound::CSound ()
   m_audioVolume     = 20;
   m_midiVolume      = 15;
   m_lastMidiVolume  = 0;
-  m_nbSuspendSkip   = 0;
   m_pMusic          = nullptr;
   m_bStopped        = false;
 
@@ -123,7 +122,7 @@ bool
 CSound::Create ()
 {
   if (
-    Mix_OpenAudio (44100, MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS, 4096) == -1)
+    Mix_OpenAudio (44100, MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS, 1024) == -1)
     return false;
 
   Mix_AllocateChannels (MAXSOUND);
@@ -407,12 +406,6 @@ CSound::RestartMusic ()
 void
 CSound::SuspendMusic ()
 {
-  if (m_nbSuspendSkip != 0)
-  {
-    m_nbSuspendSkip--;
-    return;
-  }
-
   m_bStopped = true;
   Mix_HaltMusic ();
 }
@@ -451,11 +444,3 @@ CSound::AdaptVolumeMusic ()
     m_lastMidiVolume = m_midiVolume;
   }
 }
-
-// Indique le nombre de suspend ï¿½ sauter.
-
-void
-CSound::SetSuspendSkip (Sint32 nb)
-{
-  m_nbSuspendSkip = nb;
-}
