@@ -1,7 +1,7 @@
 /*
  * This file is part of the planetblupi source code
  * Copyright (C) 1997, Daniel Roux & EPSITEC SA
- * Copyright (C) 2017-2018, Mathieu Schroeter
+ * Copyright (C) 2017-2019, Mathieu Schroeter
  * http://epsitec.ch; http://www.blupi.org; http://github.com/blupi-games
  *
  * This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,11 @@
 #include <string>
 #include <vector>
 
+#ifdef EMSCRIPTEN
+#include <SDL2/SDL_mixer.h>
+#else /* EMSCRIPTEN */
 #include <SDL_mixer.h>
+#endif /* !EMSCRIPTEN */
 
 #include "blupi.h"
 
@@ -65,7 +69,6 @@ public:
   bool IsPlayingMusic ();
   bool IsStoppedOnDemand ();
   void AdaptVolumeMusic ();
-  void SetSuspendSkip (Sint32 nb);
   void StopSound (bool immediat, Sint32 rank);
   bool StopAllSounds (bool immediat, const std::set<Sint32> * except = nullptr);
 
@@ -80,5 +83,4 @@ protected:
   Sint32                   m_audioVolume;
   Sint32                   m_midiVolume;
   Sint32                   m_lastMidiVolume;
-  Sint32                   m_nbSuspendSkip;
 };
